Rename timo-env.sh and timo-env_install.bash
These files now use the zephyr- prefix.
Change-Id: Iab24bc1fc15e7b7e40922996ba338763638644bf
Signed-off-by: Anas Nashif <anas.nashif@intel.com>
diff --git a/timo-env.sh b/timo-env.sh
index 5939711..caed24c 100644
--- a/timo-env.sh
+++ b/timo-env.sh
@@ -1,11 +1,11 @@
-if [ "X$(basename -- "$0")" == "Xtimo-env.bash" ]; then
+if [ "X$(basename -- "$0")" == "Xzephyr-env.bash" ]; then
echo "Source this file (do NOT execute it!) to set the Zephyr OS environment."
exit
fi
# You can further customize your environment by creating a bash script called
# timo-env_install.bash in your home directory. It will be automatically
# run (if it exists) by this script.
# identify OS source tree root directory
@@ -17,6 +17,6 @@
unset scripts_path
# enable custom environment settings
-timo_answer_file=~/timo-env_install.bash
-[ -f ${timo_answer_file} ] && . ${timo_answer_file}
-unset timo_answer_file
+zephyr_answer_file=~/zephyr-env_install.bash
+[ -f ${zephyr_answer_file} ] && . ${zephyr_answer_file}
+unset zephyr_answer_file
@@ -1,11 +1,11 @@
fi
# You can further customize your environment by creating a bash script called
-# timo-env_install.bash in your home directory. It will be automatically
+# zephyr-env_install.bash in your home directory. It will be automatically
# run (if it exists) by this script.
# identify OS source tree root directory